{
    "ébauches": {
        "required": True,
        "type": "dict",
        "empty": False,
        "valuesrules": {"type": "string", "nullable": True},
    },
    "tests": {
        "required": True,
        "type": "list",
        "empty": False,
        "schema": {
            "required": True,
            "type": "dict",
            "schema": {
                "nom": {"required": False, "type": "string"},
                "entrée": {
                    "required": False,
                    "type": ["string", "integer"],
                    "nullable": True,
                },
                "sortie": {
                    "required": True,
                    "type": ["string", "integer"],
                    "nullable": True,
                },
                "rétroactions": {
                    "required": False,
                    "type": "dict",
                    "schema": "rétroactions",
                },
            },
        },
    },
}



"""
progression_qc est un compilateur/validateur pour la production de d'exercices pour Progression. progression_qc reçoit sur l'entrée standard ou en paramètre un fichier YAML contenant la description d'une question et reproduit sur la sortie standard le résultat traité et validé.
"""

__version__ = "0.1.4"
__author__ = "Patrick Lafrance"



{
    "type": {"required": True, "type": "string", "regex": "^(?i)(prog|sys|bd)$"},
    "titre": {"required": False, "type": "string"},
    "description": {"required": False, "type": "string"},
    "énoncé": {"required": False, "type": "string"},
    "rétroactions": {"required": False, "type": "dict", "schema": "rétroactions"},
}
